

# /tests

Meant for functional or integration tests.
Place your unit test code in the respective `/src` directory and name it `*_test.py`

# /tests/data

Holds data required by tests under `/src` and `/test`.
